Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2557)

Unified Diff: chrome/browser/prefs/pref_service.h

Issue 10662035: [Sync] Put everything in sync/api into csync namespace (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix comments Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/prefs/pref_model_associator.cc ('k') | chrome/browser/prefs/pref_service.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/prefs/pref_service.h
diff --git a/chrome/browser/prefs/pref_service.h b/chrome/browser/prefs/pref_service.h
index 948bd34e61e66a81ca5d0598dbac5092f22e52a0..b76f32aa79aff61a0d42408de3b5cdf533612f75 100644
--- a/chrome/browser/prefs/pref_service.h
+++ b/chrome/browser/prefs/pref_service.h
@@ -29,13 +29,16 @@ class PrefNotifier;
class PrefNotifierImpl;
class PrefStore;
class PrefValueStore;
-class SyncableService;
namespace content {
class NotificationObserver;
}
-namespace policy{
+namespace csync {
+class SyncableService;
+}
+
+namespace policy {
class PolicyService;
}
@@ -318,9 +321,9 @@ class PrefService : public base::NonThreadSafe {
PrefInitializationStatus GetInitializationStatus() const;
- // SyncableService getter.
- // TODO(zea): Have PrefService implement SyncableService directly.
- SyncableService* GetSyncableService();
+ // csync::SyncableService getter.
+ // TODO(zea): Have PrefService implement csync::SyncableService directly.
+ csync::SyncableService* GetSyncableService();
// Tell our PrefValueStore to update itself using |command_line|.
// Do not call this after having derived an incognito or per tab pref service.
« no previous file with comments | « chrome/browser/prefs/pref_model_associator.cc ('k') | chrome/browser/prefs/pref_service.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698